# Tutorials

Interactive Jupyter notebook tutorials are available in the
[tutorials/ directory](https://github.com/SLDlab/neurodesign-plus/tree/master/tutorials)
of the repository.

## Overview Tutorials

| # | Tutorial | Description |
|---|---------|-------------|
| 1 | [Base Overview](https://github.com/SLDlab/neurodesign-plus/blob/master/tutorials/tutorial_1_neurodesign_base_overview.ipynb) | Introduction to the core neurodesign workflow |
| 2 | [Comparing Designs Across Experiments](https://github.com/SLDlab/neurodesign-plus/blob/master/tutorials/tutorial_2_comparing_designs_across_experiments.ipynb) | Comparing designs across diverse experiment definitions |

## Base Function Tutorials

| # | Tutorial | Description |
|---|---------|-------------|
| 3 | [Designing, Scoring, and Optimising](https://github.com/SLDlab/neurodesign-plus/blob/master/tutorials/base_functions/tutorial_base_designing_scoring_and_optimizing.ipynb) | Core workflow: designing, scoring, and optimising |
| 4 | [Comparing Designs](https://github.com/SLDlab/neurodesign-plus/blob/master/tutorials/base_functions/tutorial_base_comparing_designs.ipynb) | Side-by-side design comparison |
| 5 | [Discovering Best Design](https://github.com/SLDlab/neurodesign-plus/blob/master/tutorials/base_functions/tutorial_base_discovering_best_design.ipynb) | Finding the optimal design |
| 6 | [Optimising and Reporting](https://github.com/SLDlab/neurodesign-plus/blob/master/tutorials/base_functions/tutorial_base_optimizating_and_reporting.ipynb) | Running optimisation and generating reports |

## New Feature Tutorials

| # | Tutorial | Description |
|---|---------|-------------|
| 7 | [Controlled Probabilistic Ordering](https://github.com/SLDlab/neurodesign-plus/blob/master/tutorials/new_functions/tutorial_new_controlled_probabalistic_ordering.ipynb) | Probability-based stimulus ordering |
| 8 | [Fixed Order](https://github.com/SLDlab/neurodesign-plus/blob/master/tutorials/new_functions/tutorial_new_fixed_order.ipynb) | User-defined fixed stimulus order |
| 9 | [Varied ITI](https://github.com/SLDlab/neurodesign-plus/blob/master/tutorials/new_functions/tutorial_new_varied_ITI.ipynb) | Conditional inter-trial intervals |
| 10 | [Varied Stimuli Durations](https://github.com/SLDlab/neurodesign-plus/blob/master/tutorials/new_functions/tutorial_new_varied_stimuli_durations.ipynb) | Distribution-based stimulus durations |

:::{tip}
To run these notebooks locally, install the package in development mode and register the
Jupyter kernel. See the [installation guide](installation.md) for details.
:::
